@@ -62,12 +62,12 @@ class AioMysqlCore(object):
         :param str query: Query to execute.
         :param args: parameters used with query. (optional)
         :type args: tuple, list or dict
-        :return: lastrowid
+        :return: rowcount
         :rtype: int
         If args is a list or tuple, %s can be used as a placeholder in the query.
         If args is a dict, %(name)s can be used as a placeholder in the query.
         """
-        return await self.execute_lastrowid(query, *args, **kwargs)
+        return await self.execute_rowcount(query, *args, **kwargs)
 
     async def execute_lastrowid(self, query, *args, **kwargs):
         """Execute a query
@@ -103,12 +103,12 @@ class AioMysqlCore(object):
         """Run several data against one query
         :param query: query to execute on server
         :param args:  Sequence of sequences or mappings.  It is used as parameter.
-        :return: lastrowid.
+        :return: rowcount.
         This method improves performance on multiple-row INSERT and
         REPLACE. Otherwise it is equivalent to looping over args with
         execute().
         """
-        return await self.executemany_lastrowid(query, parameters)
+        return await self.executemany_rowcount(query, parameters)
 
     async def executemany_lastrowid(self, query, parameters):
         """Run several data against one query
@@ -168,20 +168,20 @@ class AioMysqlAlchemyCore(object):
     def __init__(self, engine):
         self.engine = engine
 
-    async def query(self, clause):
+    async def query(self, clause, **params):
         """Execute a clause
         :param TableClause clause: Query to execute.
         :return: Number of affected rows
         """
         async with self.engine.acquire() as conn:
-            return await conn.execute(clause)
+            return await conn.execute(clause, **params)
 
-    async def get(self, clause):
+    async def get(self, clause, **params):
         """Execute a clause
         :param TableClause clause: Query to execute.
         :return: Number of affected first row
         """
-        rows = await self.query(clause)
+        rows = await self.query(clause, **params)
         if not rows:
             return None
         elif rows.rowcount > 1:
@@ -190,28 +190,28 @@ class AioMysqlAlchemyCore(object):
             async for row in rows:
                 return row
 
-    async def execute(self, clause):
+    async def execute(self, clause, **params):
         """Execute a clause
         :param TableClause clause: Query to execute.
         :return: lastrowid
         """
-        return await self.execute_rowcount(clause)
+        return await self.execute_rowcount(clause, **params)
 
-    async def execute_lastrowid(self, clause):
+    async def execute_lastrowid(self, clause, **params):
         """Execute a clause
         :param TableClause clause: Query to execute.
         :type args: tuple, list or dict
         :return: lastrowid
         """
         async with self.engine.acquire() as conn:
-            r = await conn.execute(clause)
+            r = await conn.execute(clause, **params)
             return r.lastrowid
 
-    async def execute_rowcount(self, clause):
+    async def execute_rowcount(self, clause, **params):
         """Execute a clause
         :param TableClause clause: Query to execute.
         :return: rowcount
         """
         async with self.engine.acquire() as conn:
-            r = await conn.execute(clause)
+            r = await conn.execute(clause, **params)
             return r.rowcount
